# coding: utf-8

"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeListenerAttributesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'acl_ids': 'list[str]',
        'acl_status': 'str',
        'acl_type': 'str',
        'certificate_id': 'str',
        'create_time': 'str',
        'description': 'str',
        'enabled': 'str',
        'established_timeout': 'int',
        'health_check': 'HealthCheckForDescribeListenerAttributesOutput',
        'listener_id': 'str',
        'listener_name': 'str',
        'load_balancer_id': 'str',
        'port': 'int',
        'protocol': 'str',
        'request_id': 'str',
        'scheduler': 'str',
        'server_group_id': 'str',
        'status': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'acl_ids': 'AclIds',
        'acl_status': 'AclStatus',
        'acl_type': 'AclType',
        'certificate_id': 'CertificateId',
        'create_time': 'CreateTime',
        'description': 'Description',
        'enabled': 'Enabled',
        'established_timeout': 'EstablishedTimeout',
        'health_check': 'HealthCheck',
        'listener_id': 'ListenerId',
        'listener_name': 'ListenerName',
        'load_balancer_id': 'LoadBalancerId',
        'port': 'Port',
        'protocol': 'Protocol',
        'request_id': 'RequestId',
        'scheduler': 'Scheduler',
        'server_group_id': 'ServerGroupId',
        'status': 'Status',
        'update_time': 'UpdateTime'
    }

    def __init__(self, acl_ids=None, acl_status=None, acl_type=None, certificate_id=None, create_time=None, description=None, enabled=None, established_timeout=None, health_check=None, listener_id=None, listener_name=None, load_balancer_id=None, port=None, protocol=None, request_id=None, scheduler=None, server_group_id=None, status=None, update_time=None, _configuration=None):  # noqa: E501
        """DescribeListenerAttributesResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._acl_ids = None
        self._acl_status = None
        self._acl_type = None
        self._certificate_id = None
        self._create_time = None
        self._description = None
        self._enabled = None
        self._established_timeout = None
        self._health_check = None
        self._listener_id = None
        self._listener_name = None
        self._load_balancer_id = None
        self._port = None
        self._protocol = None
        self._request_id = None
        self._scheduler = None
        self._server_group_id = None
        self._status = None
        self._update_time = None
        self.discriminator = None

        if acl_ids is not None:
            self.acl_ids = acl_ids
        if acl_status is not None:
            self.acl_status = acl_status
        if acl_type is not None:
            self.acl_type = acl_type
        if certificate_id is not None:
            self.certificate_id = certificate_id
        if create_time is not None:
            self.create_time = create_time
        if description is not None:
            self.description = description
        if enabled is not None:
            self.enabled = enabled
        if established_timeout is not None:
            self.established_timeout = established_timeout
        if health_check is not None:
            self.health_check = health_check
        if listener_id is not None:
            self.listener_id = listener_id
        if listener_name is not None:
            self.listener_name = listener_name
        if load_balancer_id is not None:
            self.load_balancer_id = load_balancer_id
        if port is not None:
            self.port = port
        if protocol is not None:
            self.protocol = protocol
        if request_id is not None:
            self.request_id = request_id
        if scheduler is not None:
            self.scheduler = scheduler
        if server_group_id is not None:
            self.server_group_id = server_group_id
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time

    @property
    def acl_ids(self):
        """Gets the acl_ids of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The acl_ids of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl_ids

    @acl_ids.setter
    def acl_ids(self, acl_ids):
        """Sets the acl_ids of this DescribeListenerAttributesResponse.


        :param acl_ids: The acl_ids of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: list[str]
        """

        self._acl_ids = acl_ids

    @property
    def acl_status(self):
        """Gets the acl_status of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The acl_status of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._acl_status

    @acl_status.setter
    def acl_status(self, acl_status):
        """Sets the acl_status of this DescribeListenerAttributesResponse.


        :param acl_status: The acl_status of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._acl_status = acl_status

    @property
    def acl_type(self):
        """Gets the acl_type of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The acl_type of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._acl_type

    @acl_type.setter
    def acl_type(self, acl_type):
        """Sets the acl_type of this DescribeListenerAttributesResponse.


        :param acl_type: The acl_type of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._acl_type = acl_type

    @property
    def certificate_id(self):
        """Gets the certificate_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The certificate_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._certificate_id

    @certificate_id.setter
    def certificate_id(self, certificate_id):
        """Sets the certificate_id of this DescribeListenerAttributesResponse.


        :param certificate_id: The certificate_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._certificate_id = certificate_id

    @property
    def create_time(self):
        """Gets the create_time of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The create_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DescribeListenerAttributesResponse.


        :param create_time: The create_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def description(self):
        """Gets the description of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The description of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DescribeListenerAttributesResponse.


        :param description: The description of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """Gets the enabled of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The enabled of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DescribeListenerAttributesResponse.


        :param enabled: The enabled of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def established_timeout(self):
        """Gets the established_timeout of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The established_timeout of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: int
        """
        return self._established_timeout

    @established_timeout.setter
    def established_timeout(self, established_timeout):
        """Sets the established_timeout of this DescribeListenerAttributesResponse.


        :param established_timeout: The established_timeout of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: int
        """

        self._established_timeout = established_timeout

    @property
    def health_check(self):
        """Gets the health_check of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The health_check of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: HealthCheckForDescribeListenerAttributesOutput
        """
        return self._health_check

    @health_check.setter
    def health_check(self, health_check):
        """Sets the health_check of this DescribeListenerAttributesResponse.


        :param health_check: The health_check of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: HealthCheckForDescribeListenerAttributesOutput
        """

        self._health_check = health_check

    @property
    def listener_id(self):
        """Gets the listener_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The listener_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._listener_id

    @listener_id.setter
    def listener_id(self, listener_id):
        """Sets the listener_id of this DescribeListenerAttributesResponse.


        :param listener_id: The listener_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._listener_id = listener_id

    @property
    def listener_name(self):
        """Gets the listener_name of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The listener_name of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._listener_name

    @listener_name.setter
    def listener_name(self, listener_name):
        """Sets the listener_name of this DescribeListenerAttributesResponse.


        :param listener_name: The listener_name of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._listener_name = listener_name

    @property
    def load_balancer_id(self):
        """Gets the load_balancer_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The load_balancer_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._load_balancer_id

    @load_balancer_id.setter
    def load_balancer_id(self, load_balancer_id):
        """Sets the load_balancer_id of this DescribeListenerAttributesResponse.


        :param load_balancer_id: The load_balancer_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._load_balancer_id = load_balancer_id

    @property
    def port(self):
        """Gets the port of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The port of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this DescribeListenerAttributesResponse.


        :param port: The port of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def protocol(self):
        """Gets the protocol of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The protocol of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this DescribeListenerAttributesResponse.


        :param protocol: The protocol of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def request_id(self):
        """Gets the request_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The request_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DescribeListenerAttributesResponse.


        :param request_id: The request_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def scheduler(self):
        """Gets the scheduler of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The scheduler of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._scheduler

    @scheduler.setter
    def scheduler(self, scheduler):
        """Sets the scheduler of this DescribeListenerAttributesResponse.


        :param scheduler: The scheduler of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._scheduler = scheduler

    @property
    def server_group_id(self):
        """Gets the server_group_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The server_group_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._server_group_id

    @server_group_id.setter
    def server_group_id(self, server_group_id):
        """Sets the server_group_id of this DescribeListenerAttributesResponse.


        :param server_group_id: The server_group_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._server_group_id = server_group_id

    @property
    def status(self):
        """Gets the status of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The status of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeListenerAttributesResponse.


        :param status: The status of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The update_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DescribeListenerAttributesResponse.


        :param update_time: The update_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeListenerAttributesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeListenerAttributesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeListenerAttributesResponse):
            return True

        return self.to_dict() != other.to_dict()
