# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateVpnGatewayRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bandwidth': 'int',
        'billing_type': 'int',
        'description': 'str',
        'period': 'int',
        'period_unit': 'str',
        'project_name': 'str',
        'subnet_id': 'str',
        'tags': 'list[TagForCreateVpnGatewayInput]',
        'vpc_id': 'str',
        'vpn_gateway_name': 'str'
    }

    attribute_map = {
        'bandwidth': 'Bandwidth',
        'billing_type': 'BillingType',
        'description': 'Description',
        'period': 'Period',
        'period_unit': 'PeriodUnit',
        'project_name': 'ProjectName',
        'subnet_id': 'SubnetId',
        'tags': 'Tags',
        'vpc_id': 'VpcId',
        'vpn_gateway_name': 'VpnGatewayName'
    }

    def __init__(self, bandwidth=None, billing_type=None, description=None, period=None, period_unit=None, project_name=None, subnet_id=None, tags=None, vpc_id=None, vpn_gateway_name=None, _configuration=None):  # noqa: E501
        """CreateVpnGatewayRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bandwidth = None
        self._billing_type = None
        self._description = None
        self._period = None
        self._period_unit = None
        self._project_name = None
        self._subnet_id = None
        self._tags = None
        self._vpc_id = None
        self._vpn_gateway_name = None
        self.discriminator = None

        self.bandwidth = bandwidth
        if billing_type is not None:
            self.billing_type = billing_type
        if description is not None:
            self.description = description
        if period is not None:
            self.period = period
        if period_unit is not None:
            self.period_unit = period_unit
        if project_name is not None:
            self.project_name = project_name
        self.subnet_id = subnet_id
        if tags is not None:
            self.tags = tags
        self.vpc_id = vpc_id
        if vpn_gateway_name is not None:
            self.vpn_gateway_name = vpn_gateway_name

    @property
    def bandwidth(self):
        """Gets the bandwidth of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The bandwidth of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: int
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this CreateVpnGatewayRequest.


        :param bandwidth: The bandwidth of this CreateVpnGatewayRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and bandwidth is None:
            raise ValueError("Invalid value for `bandwidth`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                bandwidth is not None and bandwidth > 1000):  # noqa: E501
            raise ValueError("Invalid value for `bandwidth`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self._configuration.client_side_validation and
                bandwidth is not None and bandwidth < 5):  # noqa: E501
            raise ValueError("Invalid value for `bandwidth`, must be a value greater than or equal to `5`")  # noqa: E501

        self._bandwidth = bandwidth

    @property
    def billing_type(self):
        """Gets the billing_type of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The billing_type of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this CreateVpnGatewayRequest.


        :param billing_type: The billing_type of this CreateVpnGatewayRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type > 1):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value less than or equal to `1`")  # noqa: E501
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._billing_type = billing_type

    @property
    def description(self):
        """Gets the description of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The description of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateVpnGatewayRequest.


        :param description: The description of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501
        if (self._configuration.client_side_validation and
                description is not None and len(description) < 1):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `1`")  # noqa: E501

        self._description = description

    @property
    def period(self):
        """Gets the period of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The period of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this CreateVpnGatewayRequest.


        :param period: The period of this CreateVpnGatewayRequest.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def period_unit(self):
        """Gets the period_unit of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The period_unit of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_unit

    @period_unit.setter
    def period_unit(self, period_unit):
        """Sets the period_unit of this CreateVpnGatewayRequest.


        :param period_unit: The period_unit of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Month", "Year"]  # noqa: E501
        if (self._configuration.client_side_validation and
                period_unit not in allowed_values):
            raise ValueError(
                "Invalid value for `period_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(period_unit, allowed_values)
            )

        self._period_unit = period_unit

    @property
    def project_name(self):
        """Gets the project_name of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The project_name of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateVpnGatewayRequest.


        :param project_name: The project_name of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def subnet_id(self):
        """Gets the subnet_id of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The subnet_id of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this CreateVpnGatewayRequest.


        :param subnet_id: The subnet_id of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and subnet_id is None:
            raise ValueError("Invalid value for `subnet_id`, must not be `None`")  # noqa: E501

        self._subnet_id = subnet_id

    @property
    def tags(self):
        """Gets the tags of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The tags of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: list[TagForCreateVpnGatewayInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CreateVpnGatewayRequest.


        :param tags: The tags of this CreateVpnGatewayRequest.  # noqa: E501
        :type: list[TagForCreateVpnGatewayInput]
        """

        self._tags = tags

    @property
    def vpc_id(self):
        """Gets the vpc_id of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The vpc_id of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this CreateVpnGatewayRequest.


        :param vpc_id: The vpc_id of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and vpc_id is None:
            raise ValueError("Invalid value for `vpc_id`, must not be `None`")  # noqa: E501

        self._vpc_id = vpc_id

    @property
    def vpn_gateway_name(self):
        """Gets the vpn_gateway_name of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The vpn_gateway_name of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpn_gateway_name

    @vpn_gateway_name.setter
    def vpn_gateway_name(self, vpn_gateway_name):
        """Sets the vpn_gateway_name of this CreateVpnGatewayRequest.


        :param vpn_gateway_name: The vpn_gateway_name of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                vpn_gateway_name is not None and len(vpn_gateway_name) > 128):
            raise ValueError("Invalid value for `vpn_gateway_name`, length must be less than or equal to `128`")  # noqa: E501
        if (self._configuration.client_side_validation and
                vpn_gateway_name is not None and len(vpn_gateway_name) < 1):
            raise ValueError("Invalid value for `vpn_gateway_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._vpn_gateway_name = vpn_gateway_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateVpnGatewayRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVpnGatewayRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVpnGatewayRequest):
            return True

        return self.to_dict() != other.to_dict()
