# coding: utf-8

# flake8: noqa
"""
    storage_ebs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkstorageebs.models.attach_volume_request import AttachVolumeRequest
from volcenginesdkstorageebs.models.attach_volume_response import AttachVolumeResponse
from volcenginesdkstorageebs.models.create_volume_request import CreateVolumeRequest
from volcenginesdkstorageebs.models.create_volume_response import CreateVolumeResponse
from volcenginesdkstorageebs.models.delete_volume_request import DeleteVolumeRequest
from volcenginesdkstorageebs.models.delete_volume_response import DeleteVolumeResponse
from volcenginesdkstorageebs.models.describe_volumes_request import DescribeVolumesRequest
from volcenginesdkstorageebs.models.describe_volumes_response import DescribeVolumesResponse
from volcenginesdkstorageebs.models.detach_volume_request import DetachVolumeRequest
from volcenginesdkstorageebs.models.detach_volume_response import DetachVolumeResponse
from volcenginesdkstorageebs.models.extend_volume_request import ExtendVolumeRequest
from volcenginesdkstorageebs.models.extend_volume_response import ExtendVolumeResponse
from volcenginesdkstorageebs.models.modify_volume_attribute_request import ModifyVolumeAttributeRequest
from volcenginesdkstorageebs.models.modify_volume_attribute_response import ModifyVolumeAttributeResponse
from volcenginesdkstorageebs.models.volume_for_describe_volumes_output import VolumeForDescribeVolumesOutput
